@@ -7,37 +7,43 @@
 #' history of calls and md5hashes of partial results. The overloaded 
 #' \code{print.ahistory} function prints this history in a concise way. The overloaded
 #' \code{print.ahistoryKable} function prints this history in the same way as \link[knitr]{kable}.
+#' When \code{alink=TRUE} one can create history table/kable with hooks to partial results (artifacts) as in the \link{alink} function.
 #' 
 #' @details
-#' All artifacts created with operator \link[archivist]{\%a\%} are archivised with 
+#' All artifacts created with \link[archivist]{\%a\%} operator are archivised with 
 #' detailed information  about it's source (both call and md5hash of the input).
 #' The function \code{ahistory} reads all artifacts that 
 #' precede \code{artifact} and create a description of the input flow. 
 #' The generic \code{print.ahistory} function plots the history in a human readable  way.
 #' 
-#' @param artifact An artifact for which history should be derived. Will be converted  into md5hash.
+#' @param artifact An artifact which history is supposed to be reconstructed.
+#' It will be converted  into md5hash.
 #' @param md5hash  If \code{artifact} is not specified then \code{md5hash} is used.
 #' @param repoDir  A character denoting an existing directory in which an artifact will be saved.
-#' If set to \code{NULL} (by default), uses the \code{repoDir} specified in \link{setLocalRepo}.
-#' @param ...  Further parameters passed to \link[knitr]{kable} function. Used when \code{aformat = "kable"}.
-#' @param aformat A character denoting whether to print history in a \code{"regular"} (default) way or like in a \code{"kable"} function.
+#' @param ...  Further parameters passed to \link{alink} function. Used when \code{format = "kable"} and \code{alink = TRUE}.
+#' @param format A character denoting whether to print history in either a \code{"regular"} (default) way or like in a \code{"kable"} function.
 #' See Notes.
+#' @param alink Whether to provide hooks to objects like in \link{alink}. See examples.
 #' 
-#' @return This function returns data frame with two columns - names of calls and md5hashes of partial results.
+#' @return A data frame with two columns - names of calls and md5hashes of partial results.
 #' 
 #' @note There are provided functions (\code{print.ahistory} and \code{print.ahistoryKable}) to print the artifact's history. 
-#' History can be printed in a \code{regular} way which is friendy for the console output or in a \code{kable} format which 
-#' prints the artifact's history in a way in which \link[knitr]{kable} function would. This is convenient when one prints history
-#' in \code{.Rmd} files using \link[rmarkdown]{rmarkdown}
+#' History can be printed either in a \code{regular} way which is friendy for the console output or in a \code{kable} format which 
+#' prints the artifact's history in a way \link[knitr]{kable} function would. This is convenient when one prints history
+#' in \code{.Rmd} files using \link[rmarkdown]{rmarkdown}.
+#' 
+#' Moreover when user passes \code{format = 'kable'} and \code{alink = TRUE} then one can use links for remote Repository. 
+#' Then mdhashes are taken from Local Repository, so user has to specify \code{repo}, \code{user} and \code{repoDir} even though 
+#' they are set globally, because \code{repo} is a substring of \code{repoDir} and during evalutation of \code{...} R treats \code{repo} as \code{repoDir}.
 #' 
 #' @author 
 #' Przemyslaw Biecek, \email{przemyslaw.biecek@@gmail.com}
 #' 
-#' @examples
-#' \dontrun{
+#' Marcin Kosinski, \email{m.p.kosinski@@gmail.com}
 #' 
-#' createEmptyRepo("ahistory_check", default = TRUE)
-#' aoptions("silent", TRUE)
+#' @examples
+#' 
+#' createLocalRepo("ahistory_check", default = TRUE)
 #' library(dplyr)
 #' iris %a%
 #' filter(Sepal.Length < 6) %a%
@@ -45,22 +51,28 @@
 #'  summary() -> artifact
 #'  
 #' ahistory(artifact)
-#' ahistory(artifact, aformat = "kable")  
-#' print(ahistory(artifact, aformat = "kable"), format = "latex")
+#' ahistory(artifact, format = "kable")  
+#' print(ahistory(artifact, format = "kable"), format = "latex")
+#' ahistory(artifact, format = "kable", alink = TRUE, repoDir = "ahistory_check",
+#' repo = "repo", user = "user")
+#' 
+#' 
+#' repoDir <- file.path(getwd(), "ahistory_check")
+#' deleteLocalRepo(repoDir, deleteRoot = TRUE)
+#' aoptions('repoDir', NULL, unset = TRUE)
 #' 
-#' }
 #' @family archivist
 #' @rdname ahistory
 #' @export
 
-ahistory <- function(artifact = NULL, md5hash = NULL, repoDir = NULL, aformat = "regular") {
+ahistory <- function(artifact = NULL, md5hash = NULL, repoDir = aoptions('repoDir'), format = "regular", alink = FALSE, ...) {
   # if artifact is set then calculate md5hash for it
   if (!is.null(artifact)) 
     md5hash = digest(artifact)
   if (is.null(md5hash)) 
     stop("Either artifact or md5hash has to be set")
   
-  stopifnot(length(aformat) ==1 & aformat %in% c("regular", "kable"))
+  stopifnot(length(format) == 1 & format %in% c("regular", "kable"))
   
   res_names <- c()
   res_md5 <- md5hash
@@ -78,8 +90,18 @@ ahistory <- function(artifact = NULL, md5hash = NULL, repoDir = NULL, aformat =
       } else {
        # that's should not happen
         df <- data.frame(md5hash = res_md5, call = rep("", length(res_md5)), stringsAsFactors = FALSE)
-        if (aformat == "kable") {
-          class(df) = c("ahistoryKable", "data.frame")  
+        if (format == "kable") {
+          class(df) = c("ahistoryKable", "data.frame") 
+          if (alink) {
+            df$md5hash <- paste0("[",
+                                df$md5hash,
+                                "]",
+                                sapply(df$md5hash, alink, ...) %>%
+                                  as.vector() %>%
+                                  strsplit(split = "]") %>%
+                                  lapply(`[[`, 2)
+            )
+          }
         } else {
           class(df) = c("ahistory", "data.frame")  
         }
@@ -98,8 +120,18 @@ ahistory <- function(artifact = NULL, md5hash = NULL, repoDir = NULL, aformat =
     res_names[max(length(res_md5), length(res_names))+1] = ""
   }
   df <- data.frame(md5hash = res_md5, call = res_names, stringsAsFactors = FALSE)
-  if (aformat == "kable") {
+  if (format == "kable") {
     class(df) = c("ahistoryKable", "data.frame")  
+    if (alink) {
+      df$md5hash <- paste0("[",
+                           df$md5hash,
+                           "]",
+                           sapply(df$md5hash, alink, ...) %>%
+                             as.vector() %>%
+                             strsplit(split = "]") %>%
+                             lapply(`[[`, 2)
+      )
+    }
   } else {
     class(df) = c("ahistory", "data.frame")  
   }
